[−][src]Struct mdbook::theme::Theme
The Theme struct should be used instead of the static variables because
the new() method will look if the user has a theme directory in their
source folder and use the users theme instead of the default.
You should only ever use the static variables directly if you want to override the user's theme with the defaults.
Fields
index: Vec<u8>header: Vec<u8>chrome_css: Vec<u8>general_css: Vec<u8>print_css: Vec<u8>variables_css: Vec<u8>favicon: Vec<u8>js: Vec<u8>highlight_css: Vec<u8>tomorrow_night_css: Vec<u8>ayu_highlight_css: Vec<u8>highlight_js: Vec<u8>clipboard_js: Vec<u8>Methods
impl Theme[src]
pub fn new<P: AsRef<Path>>(theme_dir: P) -> Self[src]
Creates a Theme from the given theme_dir.
If a file is found in the theme dir, it will override the default version.